==> piwigo-2.7.4.zip: piwigo/plugins/TakeATour/language/bg_BG/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2014 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['Next '] = 'Напред';
$lang['Prev'] = 'Назад';
$lang['TAT_descrp'] = 'Добре дошли! Тук е списъка с всички налични описания с помощ за да откриети новите възможности на Piwigo. <br><br> Стартирайте помощника и следвайте инструкциите. Натискайте Напред/Назад или ползвайте стрелките за навигация в обиколката. Ако ви е омръзнала и не желаете да завършите обиколката, отидете на Добавки в Админ меню - Направете обиколка!';
$lang['privacy_descrp'] = 'Тази обиколка показва всички начини да защитите вашите снимки от публичен достъп без позволение на ниво снимка, албум и прочие. Използване на защити против копиране.';
$lang['first_contact_descrp'] = 'Препоръчително за начинаещи, тази обиколка ще ви запознае с Piwigo и неговите основни възможности. Ще започне с това как да добавяте снимки и да ги редактирате. Също ще видите създаване и редакция на албуми и накрая конфигуриране и настройки на теми и приложиния добавки.';
$lang['takeatour_configpage'] = 'Направете обиколка - списък';
$lang['Visit your Piwigo!'] = 'Посетете вашата Piwigo!';
$lang['Take a tour and discover the features of your Piwigo gallery » Go to the available tours'] = 'Запознайте се и разгледайте новите възможности на вашата Piwigo галерия. ';
$lang['Start the Tour'] = 'Започни прегледа';
$lang['Privacy'] = 'Защита на данни';
$lang['First Contact'] = 'За първи път';
$lang['2.7 Tour'] = '2.7 версия преглед';
$lang['End tour'] = 'Край на прегледа';
$lang['2_7_0_descrp'] = 'Вижти какво е ново в Piwigo 2.7';

==> piwigo-15.5.0.zip: piwigo/plugins/TakeATour/language/bg_BG/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2014 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['Next '] = 'Напред';
$lang['Prev'] = 'Назад';
$lang['TAT_descrp'] = 'Добре дошли! Тук е списъка с всички налични описания с помощ за да откриети новите възможности на Piwigo. <br><br> Стартирайте помощника и следвайте инструкциите. Натискайте Напред/Назад или ползвайте стрелките за навигация в обиколката. Ако ви е омръзнала и не желаете да завършите обиколката, отидете на Добавки в Админ меню - Направете обиколка!';
$lang['privacy_descrp'] = 'Тази обиколка показва всички начини да защитите вашите снимки от публичен достъп без позволение на ниво снимка, албум и прочие. Използване на защити против копиране.';
$lang['first_contact_descrp'] = 'Препоръчително за начинаещи, тази обиколка ще ви запознае с Piwigo и неговите основни възможности. Ще започне с това как да добавяте снимки и да ги редактирате. Също ще видите създаване и редакция на албуми и накрая конфигуриране и настройки на теми и приложиния добавки.';
$lang['takeatour_configpage'] = 'Направете обиколка - списък';
$lang['Visit your Piwigo!'] = 'Посетете вашата Piwigo!';
$lang['Take a tour and discover the features of your Piwigo gallery » Go to the available tours'] = 'Запознайте се и разгледайте новите възможности на вашата Piwigo галерия. ';
$lang['Start the Tour'] = 'Започни прегледа';
$lang['Privacy'] = 'Защита на данни';
$lang['First Contact'] = 'За първи път';
$lang['2.7 Tour'] = '2.7 версия преглед';
$lang['End tour'] = 'Край на прегледа';
$lang['2_7_0_descrp'] = 'Вижти какво е ново в Piwigo 2.7';
$lang['2_8_0_descrp'] = 'Разгледайте новостите в  Piwigo версия 2.8 Прочетете повече <a href="%s">в обяснителните бележки</a>.';
$lang['2.8 Tour'] = 'вер. 2.8 новини';
$lang['plugins_descrp'] = 'Плъгините са важни ключови добавки, надстройващи вашата галерия. Активирайте тези, които мислите, че са необходими за вашите нужди.';
$lang['manage_albums_descrp'] = 'Вашите албуми са важни в оформянето на вашата галерия. Научете как да ги организирате и да редактирате техните настройки.';
$lang['edit_photos_descrp'] = 'Снимките са основни елементи във вашата галерия. Вижте как можете да промените техните настройки, по една или в заедно по няколко.';
$lang['plugins_name'] = 'Плъгини';
$lang['manage_albums_name'] = 'Редакция албуми';
$lang['edit_photos_name'] = 'Редакция снимки';
$lang['config_name'] = 'Конфигуриране';
$lang['config_descrp'] = 'Конфигурирайте вашите Piwigo настройки. Откриите мениджъра на теми и изберете подходящето за вашата галерия.';
$lang['2_9_0_descrp'] = 'Откриите новостите в Piwigo 2.9. Прочетете подробно на a href="%s">бележки за новата версия</a>.';
$lang['2_9_0_name'] = '2.9 Преглед';
